# LiveKit Plugins AssemblyAI

Agent Framework plugin for AssemblyAI. Currently supports Streaming Speech-to-Text.

## Installation

```bash
pip install livekit-plugins-assemblyai
```

## Pre-requisites

You'll need to specify an AssemblyAI API Key. It can be set as environment variable: `ASSEMBLYAI_API_KEY`.
